@@ -323,7 +323,7 @@ lcmDistributesOverGcd = axiom
 dividesPlus :: (Divides a b, Divides a c) :- Divides a (b + c)
 dividesPlus = Sub axiom
 
-dividesTimes :: (Divides a b, Divides a c) :- Divides a (b * c)
+dividesTimes :: Divides a b :- Divides a (b * c)
 dividesTimes = Sub axiom
 
 dividesMin :: (Divides a b, Divides a c) :- Divides a (Min b c)
@@ -332,7 +332,10 @@ dividesMin = Sub axiom
 dividesMax :: (Divides a b, Divides a c) :- Divides a (Max b c)
 dividesMax = Sub axiom
 
-dividesDef :: forall a b. Divides a b :- ((a * Div b a) ~ b)
+-- This `dividesDef` is simpler and more convenient than Divides a b :- ((a * Div b a) ~ b)
+-- because the latter can be easily derived via 'euclideanNat', but not vice versa.
+
+dividesDef :: forall a b. Divides a b :- (Mod b a ~ 0)
 dividesDef = Sub axiom
 
 dividesPow :: (1 <= n, Divides a b) :- Divides a (b^n)
